"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _get = _interopRequireDefault(require("lodash/get"));

var _set = _interopRequireDefault(require("lodash/set"));

var _validate = _interopRequireDefault(require("./validate"));

var _form = require("./form");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const useField = name => {
  const {
    errors,
    rules,
    values,
    setErrors,
    hasBlurred,
    updateValue,
    valuesBlurred
  } = _react.default.useContext(_form.FormContext);

  let value = (0, _get.default)(values, name); // Pulling out just this field's errors

  let fieldErrors = errors.filter(error => error.name === name).map(error => error.message); //Args needed for validation

  let validationProps = {
    values,
    rules,
    valuesBlurred,
    setErrors,
    errors
  };

  const handleChange = (value, field) => {
    /*
      If this field 
      - has errors
      - blurred before
      - has dependant rules
      check validation on change
    */
    if (fieldErrors.length || valuesBlurred[field || name]) {
      let newValues = { ...values
      };
      (0, _set.default)(newValues, field || name, value);
      (0, _validate.default)({ ...validationProps,
        values: newValues,
        valuesBlurred: { ...valuesBlurred,
          [field || name]: true
        }
      });
    }

    updateValue(field || name, value);
  };
  /*
    When blurring for the first time, 
    lets send hasBlurred, and validate the field
  */


  const handleBlur = () => {
    hasBlurred(name);
    (0, _validate.default)({ ...validationProps,
      valuesBlurred: { ...valuesBlurred,
        [name]: true
      }
    });
  };

  return {
    handleBlur,
    handleChange,
    value,
    values,
    errors: fieldErrors.length ? fieldErrors : null
  };
};

var _default = useField;
exports.default = _default;