import React, { useState } from 'react';
import set from 'lodash/set';
const FormContext = React.createContext({});

function Form({
  children,
  onValues,
  values,
  rules
}) {
  let [errors, setErrors] = useState([]);
  let [valuesBlurred, setValuesBlurred] = useState({});
  return React.createElement(FormContext.Provider, {
    value: {
      rules: rules || {},
      values,
      errors,
      setErrors,
      valuesBlurred,
      setValuesBlurred,
      hasBlurred: name => {
        if (valuesBlurred[name]) return; //Store list of values that have been touched, so we can run validation on them now

        setValuesBlurred({ ...valuesBlurred,
          [name]: true
        });
      },
      updateValue: (name, value) => {
        let newValues = { ...values
        };
        set(newValues, name, value);
        onValues(newValues);
      }
    }
  }, children);
}

const FormContextConsumer = FormContext.Consumer;
export { FormContext, Form, FormContextConsumer };